@@ -9,7 +9,7 @@ import (
 	"io"
 
 	"github.com/wader/fq/format"
-	"github.com/wader/fq/internal/gojqex"
+	"github.com/wader/fq/internal/gojqx"
 	"github.com/wader/fq/pkg/bitio"
 	"github.com/wader/fq/pkg/decode"
 	"github.com/wader/fq/pkg/interp"
@@ -83,11 +83,11 @@ func toCSV(_ *interp.Interp, c []any, opts ToCSVOpts) any {
 		w.Comma = rune(opts.Comma[0])
 	}
 	for _, row := range c {
-		rs, ok := gojqex.Cast[[]any](row)
+		rs, ok := gojqx.Cast[[]any](row)
 		if !ok {
-			return fmt.Errorf("expected row to be an array, got %s", gojqex.TypeErrorPreview(row))
+			return fmt.Errorf("expected row to be an array, got %s", gojqx.TypeErrorPreview(row))
 		}
-		vs, ok := gojqex.NormalizeToStrings(rs).([]any)
+		vs, ok := gojqx.NormalizeToStrings(rs).([]any)
 		if !ok {
 			panic("not array")
 		}
@@ -95,7 +95,7 @@ func toCSV(_ *interp.Interp, c []any, opts ToCSVOpts) any {
 		for _, v := range vs {
 			s, ok := v.(string)
 			if !ok {
-				return fmt.Errorf("expected row record to be scalars, got %s", gojqex.TypeErrorPreview(v))
+				return fmt.Errorf("expected row record to be scalars, got %s", gojqx.TypeErrorPreview(v))
 			}
 			ss = append(ss, s)
 		}
