@@ -134,6 +134,7 @@ var (
 	MachO_Fat           = &decode.Group{Name: "macho_fat"}
 	Markdown            = &decode.Group{Name: "markdown"}
 	Matroska            = &decode.Group{Name: "matroska"}
+	MIDI                = &decode.Group{Name: "midi"}
 	MOC3                = &decode.Group{Name: "moc3"}
 	MP3                 = &decode.Group{Name: "mp3"}
 	MP3_Frame           = &decode.Group{Name: "mp3_frame"}
@@ -147,6 +148,7 @@ var (
 	MPEG_TS             = &decode.Group{Name: "mpeg_ts"}
 	MPES_PES            = &decode.Group{Name: "mpeg_pes"}
 	MsgPack             = &decode.Group{Name: "msgpack"}
+	Negentropy          = &decode.Group{Name: "negentropy"}
 	NES                 = &decode.Group{Name: "nes"}
 	Ogg                 = &decode.Group{Name: "ogg"}
 	Ogg_Page            = &decode.Group{Name: "ogg_page"}
@@ -165,12 +167,14 @@ var (
 	RTMP                = &decode.Group{Name: "rtmp"}
 	SLL_Packet          = &decode.Group{Name: "sll_packet"}
 	SLL2_Packet         = &decode.Group{Name: "sll2_packet"}
+	TAP                 = &decode.Group{Name: "tap"}
 	TAR                 = &decode.Group{Name: "tar"}
 	TCP_Segment         = &decode.Group{Name: "tcp_segment"}
 	TIFF                = &decode.Group{Name: "tiff"}
 	TLS                 = &decode.Group{Name: "tls"}
 	TOML                = &decode.Group{Name: "toml"}
 	Tzif                = &decode.Group{Name: "tzif"}
+	TZX                 = &decode.Group{Name: "tzx"}
 	UDP_Datagram        = &decode.Group{Name: "udp_datagram"}
 	Vorbis_Comment      = &decode.Group{Name: "vorbis_comment"}
 	Vorbis_Packet       = &decode.Group{Name: "vorbis_packet"}
