@@ -3,6 +3,7 @@ package yaml
 // TODO: yaml type eval? walk eval?
 
 import (
+	"bytes"
 	"embed"
 	"errors"
 	"io"
@@ -30,7 +31,7 @@ func init() {
 			Functions:   []string{"_todisplay"},
 		})
 	interp.RegisterFS(yamlFS)
-	interp.RegisterFunc0("to_yaml", toYAML)
+	interp.RegisterFunc1("_to_yaml", toYAML)
 }
 
 func decodeYAML(d *decode.D) any {
@@ -61,10 +62,20 @@ func decodeYAML(d *decode.D) any {
 	return nil
 }
 
-func toYAML(_ *interp.Interp, c any) any {
-	b, err := yaml.Marshal(gojqx.Normalize(c))
-	if err != nil {
+type ToYAMLOpts struct {
+	Indent int `default:"4"` // 4 is default for gopkg.in/yaml.v3
+}
+
+func toYAML(_ *interp.Interp, c any, opts ToYAMLOpts) any {
+	b := &bytes.Buffer{}
+	e := yaml.NewEncoder(b)
+	// yaml.SetIndent panics if < 0
+	if opts.Indent >= 0 {
+		e.SetIndent(opts.Indent)
+	}
+	if err := e.Encode(gojqx.Normalize(c)); err != nil {
 		return err
 	}
-	return string(b)
+
+	return b.String()
 }
