@@ -13,7 +13,6 @@ import (
 	"path/filepath"
 	"runtime"
 
-	"github.com/wader/fq/internal/mathx"
 	"github.com/wader/fq/pkg/interp"
 	"golang.org/x/term"
 
@@ -82,8 +81,9 @@ func newStandardOS() *stdOS {
 
 func (stdOS) Platform() interp.Platform {
 	return interp.Platform{
-		OS:   runtime.GOOS,
-		Arch: runtime.GOARCH,
+		OS:        runtime.GOOS,
+		Arch:      runtime.GOARCH,
+		GoVersion: runtime.Version(),
 	}
 }
 
@@ -92,7 +92,7 @@ type fdTerminal uintptr
 func (fd fdTerminal) Size() (int, int) {
 	w, h, _ := term.GetSize(int(fd))
 	// TODO: old version return 0 on no terminal
-	w, h = mathx.Max(0, w), mathx.Max(0, h)
+	w, h = max(0, w), max(0, h)
 	return w, h
 }
 func (fd fdTerminal) IsTerminal() bool {
